@@ -61,11 +61,11 @@ check_var <- function(vars, varn, varntype = NULL, dataset,
       if (varntype == "numeric01") if (length(vars) != 1 | any(!is.numeric(vars) |  vars < 0 | vars > 1)) {
                                                      stop(paste0("'", varn, "' must be a numeric value in [0, 1]"), call. = FALSE)  }
       if (varntype == "integer0100") {
-                      if ((length(vars) != 1 & varn != "k") | any(!is.integer(vars) |  vars < 0 | vars > 100)) {
-                                    stop(paste0("'", varn, "' must be a integer value", ifelse(varn != "k", "s", ""), " in [0, 100]"), call. = FALSE)  }}
+                      if (length(vars) != 1 | any(!is.integer(vars) |  vars < 0 | vars > 100)) {
+                                    stop(paste0("'", varn, "' must be a integer value in [0, 100]"), call. = FALSE)  }}
 
-     if (varntype == "numeric0100") if (length(vars) != 1 | any(!is.numeric(vars) |  vars < 0 | vars > 100)) {
-                                                  stop(paste0("'", varn, "' must be a numeric value in [0, 100]"), call. = FALSE)  }
+     if (varntype == "numeric0100") if ((length(vars) != 1  & !(varn %in% c("k", "order_quant"))) | any(!is.numeric(vars) |  vars < 0 | vars > 100)) {
+                                                  stop(paste0("'", varn, "' must be a numeric value", ifelse(varn != "k", "s", ""), " in [0, 100]"), call. = FALSE)  }
       if (varntype == "change_type") if (length(vars) != 1 | any(!(vars %in% c("absolute", "relative")))) {
                                                   stop("'change_type' must be 'absolute' or 'relative'", call. = FALSE)  }
       if (varntype == "method") if (length(vars) != 1 | any(!(vars %in% c("cros", "netchanges")))) {
@@ -73,6 +73,7 @@ check_var <- function(vars, varn, varntype = NULL, dataset,
    }
 
   if (!is.null(vars) & !is.null(varntype)) mustbedefined <- FALSE
+
   if (!is.null(vars) & is.null(varntype)) {
       if (!withperiod & varn == "period") stop(paste0("'period' must be NULL for those data"), call. = FALSE)
       if(!is.null(dataset)) {
