@@ -99,7 +99,7 @@ vardom <- function(Y, H, PSU, w_final,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
                         isvector = TRUE, dX = "X")
     }
-  dataset <- NULL
+  N <- dataset <- NULL
 
   # N_h
   np <- sum(ncol(period))
@@ -132,6 +132,7 @@ vardom <- function(Y, H, PSU, w_final,
                                   checking = FALSE) else Y1 <- Y
   Y <- NULL
   n_nonzero <- copy(Y1)
+  Z1 <- NULL
   if (!is.null(period)){ n_nonzero <- data.table(period, n_nonzero)
                          n_nonzero <- n_nonzero[, lapply(.SD, function(x)
                                                           sum(as.integer(abs(x) > .Machine$double.eps))),
@@ -159,7 +160,7 @@ vardom <- function(Y, H, PSU, w_final,
   linratio_outp <- variableZ <- estim <- deff_sam <- NULL
   deff_est <- deff <- var_est2 <- se <- rse <- cv <- NULL
   absolute_margin_of_error <- relative_margin_of_error <- NULL
-  S2_y_HT <- S2_y_ca <- S2_res <- Z1 <- CI_lower <- CI_upper <- NULL
+  S2_y_HT <- S2_y_ca <- S2_res <- CI_lower <- CI_upper <- NULL
   variable <- deff_sam <- deff_est <- deff <- n_eff <- NULL
 
   aH <- names(H)
@@ -227,22 +228,29 @@ vardom <- function(Y, H, PSU, w_final,
   # Calibration
 
   res_outp <- NULL
+  betas <- NULL
   if (!is.null(X)) {
         if (!is.null(period)) ind_gr <- data.table(ind_gr, period)
+        ind_gr1 <- copy(ind_gr)
         ind_gr <- do.call("paste", c(as.list(ind_gr), sep = "_"))
 
-        lin1 <- lapply(split(Y2[,.I], ind_gr), function(i)
-                        data.table(sar_nr = i,
-                                   residual_est(Y = Y2[i],
-                                                X = X[i],
-                                                weight = w_design[i],
-                                                q = q[i],
-                                                dataset = NULL,
-                                                checking = FALSE)))
-        Y3 <- rbindlist(lin1)
-        X <- g <- q <- NULL
+        lin1 <- lapply(split(Y2[,.I], ind_gr), function(i) {
+                       resid <- residual_est(Y = Y2[i],
+                                             X = X[i],
+                                             weight = w_design[i],
+                                             q = q[i],
+                                             dataset = NULL,
+                                             checking = FALSE)
+                       pers0 <- ind_gr1[i, .N, keyby = c(names(ind_gr1))]
+                       list(data.table(sar_nr = i, resid$residuals),
+                            data.table(pers0[, N := NULL], resid$betas))
+                                    })
+
+        Y3 <- rbindlist(lapply(lin1, function(x) x[[1]]))
+        betas <- rbindlist(lapply(lin1, function(x) x[[2]]))
         setkeyv(Y3, "sar_nr")
         Y3[, sar_nr := NULL]
+        lin1 <- X <- g <- q <- NULL
         if (outp_res) res_outp <- data.table(idper, PSU, Y3)
     } else Y3 <- Y2
 
@@ -405,5 +413,6 @@ vardom <- function(Y, H, PSU, w_final,
 
   list(lin_out = linratio_outp,
        res_out = res_outp,
+       betas = betas,      
        all_result = all_result)
 }
