@@ -82,7 +82,7 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
                         isvector = TRUE)
     }
-  dataset <- NULL
+  N <- dataset <- NULL
 
   # N_h
   if (!is.null(N_h)) {
@@ -136,6 +136,16 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
                                   checking = FALSE) else Y1 <- Y
 
   n_nonzero <- copy(Y1)
+  Z1 <- NULL
+  if (!is.null(Z)) {
+     if (!is.null(Dom)) Z1 <- domain(Y = Z, D = Dom,
+                                     dataset = NULL,
+                                     checking = FALSE) else Z1 <- Z
+     Z0 <- copy(Z1)
+     setnames(Z0, names(Z0), names(Y1))
+     n_nonzero <- n_nonzero + Y1
+     Z0 <- NULL  
+    }
   if (!is.null(period)){ n_nonzero <- data.table(period, n_nonzero) 
                          n_nonzero <- n_nonzero[, lapply(.SD, function(x) 
                                                          sum(as.integer(abs(x) > .Machine$double.eps))),
@@ -168,11 +178,7 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
   idper <- id
   if (!is.null(period)) idper <- data.table(idper, period)
 
-  Z1 <- NULL
   if (!is.null(Z)) {
-    if (!is.null(Dom)) Z1 <- domain(Y = Z, D = Dom,
-                                    dataset = NULL,
-                                    checking = FALSE) else Z1 <- Z
     if (is.null(period)) {
           Y2 <- lin.ratio(Y = Y1, Z = Z1, weight = w_final,
                           Dom = NULL, dataset = NULL,
@@ -199,21 +205,27 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
   Y <- Z <- NULL
 
   # Calibration
-  res_outp <- NULL
+  betas <- res_outp <- NULL
   if (!is.null(X)) {
         ind_gr <- data.table(nsk = rep(1, nrow(X)))
         if (!is.null(period)) ind_gr <- data.table(ind_gr, period)
+        ind_gr1 <- copy(ind_gr)
         ind_gr <- do.call("paste", c(as.list(ind_gr), sep = "_"))
 
-        lin1 <- lapply(split(Y2[, .I], ind_gr), function(i) 
-                        data.table(sar_nr = i,
-                                   residual_est(Y = Y2[i],
-                                                X = X[i],
-                                                weight = w_design[i],
-                                                q = q[i],
-                                                dataset = NULL,
-                                                checking = FALSE)))
-        Y3 <- rbindlist(lin1)
+        lin1 <- lapply(split(Y2[, .I], ind_gr), function(i) {
+                       resid <- residual_est(Y = Y2[i],
+                                             X = X[i],
+                                             weight = w_design[i],
+                                             q = q[i],
+                                             dataset = NULL,
+                                             checking = FALSE)
+                       pers0 <- ind_gr1[i, .N, keyby = c(names(ind_gr1))]
+                       list(data.table(sar_nr = i, resid$residuals),
+                            data.table(pers0[, N := NULL], resid$betas))
+                   })
+
+        Y3 <- rbindlist(lapply(lin1, function(x) x[[1]]))
+        betas <- rbindlist(lapply(lin1, function(x) x[[2]]))
         setkeyv(Y3, "sar_nr")
         Y3[, sar_nr := NULL] 
       if (outp_res) res_outp <- data.table(idper, PSU, Y3)
@@ -376,6 +388,7 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
   all_result <- all_result[, c("variable", names(Dom), names(period), variab), with = FALSE]
   list(lin_out = linratio_outp,
        res_out = res_outp,
+       betas = betas,
        s2g = s2g,
        all_result = all_result)
 }
